@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 """
-Created on Tue Jun 26 18:48:03 2018
-
-@author: adutz
+title: TrussPy - Truss Solver for Python
+author: Andreas Dutzler
+year: 2023
 """
 
 import numpy as np
@@ -27,9 +27,6 @@ class BoundaryU:
         Array of boundary components: `array([U1, U2, U3])`.
         Set 1 for active (free) DOF and 0 for inactive (locked) DOF.
 
-    Todo
-    ----
-    - rename to DOFState or something similar
     """
 
     def __init__(self, node, values):
