@@ -1,27 +1,11 @@
 # -*- coding: utf-8 -*-
 """
-Created on Wed Jun 27 21:08:10 2018
-
-@author: adutz
-
-    TrussPy - Object Oriented Truss Solver for Python
-    Copyright (C) 2023  Andreas Dutzler
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+title: TrussPy - Truss Solver for Python
+author: Andreas Dutzler
+year: 2023
 """
+
 import copy
-import os
 import sys
 import time
 from subprocess import run as sp_run
@@ -61,103 +45,87 @@ class Model:
     ----------
     stdout : sys.stdout
         get current stdout
-
     file : None or str
         name of input file (default is None)
-
     log : int
         Level of collecting logging informations during analysis.
         Higher numbers will collect more informations (default is 2).
-
     logfile : boolean
         flag for logfile creation (default is True)
-
     Nodes : NodeHandler
         Handles all nodes inside the model
-
     Elements : ElementHandler
         Handles all elements inside the model
-
     Boundaries : BoundaryHandler
         Handles all boundaries inside the model
-
     ExtForces : ExternalForceHandler
         Handles all external forces inside the model
-
     Analysis : AnalysisHandler
         Handles all data for one increment
-
     Results : ResultHandler
         Handles all result data inside the model.
         A collection of all converged analysis solutions.
-
     Settings : SettingsHandler
         Handles all model parameters inside the model
 
-    Todo
-    ----
-    * move g(V), dgdV(V) from Model class to path_tracing function
     """
 
     def __init__(self, file=None, log=2, logfile=False, logfile_name="analysis"):
-        """Init Model class with default values. If input file is specified,
-        collect all data and create model.
+        """Init Model class with Nodes, Elements, Boundaries, etc. with default values.
+        If an input file is specified, collect all data and create the model.
 
-        Parameter
-        ---------
+        Parameters
+        ----------
         file : None or str, optional
-            name of input file (default is None)
-
+            Name of input file (default is None).
         log : int
-            Level of collecting logging informations during analysis.
-            Higher numbers will collect more informations (default is 2).
-
+            Level of collecting logging informations during analysis. Higher numbers
+            will collect more informations (default is 2).
         logfile : boolean, optional
             flag for logfile creation (default is True)
+        logfile_name : str, optional
+            The name of the log file (default is "analysis").
+
         """
+
         self.stdout = sys.stdout
         self.file = file
         self.logfile = logfile
-        if file is None:
-            pass
-            # self.logfile = False
 
         if self.file is not None:
+            # extract base name of input file without file extension and use it as
+            # log file name
             self.logfile_name = ".".join(self.file.split(".")[:-1])
         else:
             self.logfile_name = logfile_name
-            # self.logfile = False
+
         if self.logfile:
             sys.stdout = open(self.logfile_name + ".md", "w")
-            print(
-                r"<script src='https://cdn.mathjax.org/mathjax/latest/MathJax.js?config=TeX-AMS-MML_HTMLorMML'></script>"
-            )
 
         if log > 1:
-            print(
-                """
-         _____                  ______      
-        |_   _|                 | ___ \     
-          | |_ __ _   _ ___ ___ | |_/ /   _ 
-          | | '__| | | / __/ __||  __/ | | |
-          | | |  | |_| \__ \__ \| |  | |_| |
-          \_/_|   \__,_|___/___/\_|   \__, |
-                                       __/ |
-                                      |___/ 
-        
-        TrussPy - Object Oriented Truss Solver for Python
-                  Version {__version__}
 
-        Author: Dutzler A.
-                Graz University of Technology, 2018
-                
-        TrussPy Copyright (C) 2023  Andreas Dutzler
-        This program comes with ABSOLUTELY NO WARRANTY; 
-        for details type `trusspy.show_w()'.
-        This is free software, and you are welcome to redistribute it
-        under certain conditions; type `trusspy.show_c()' for details.
+            if self.logfile:
+                print("```")
+
+            print(
+                f"""
+ _____                  ______      
+|_   _|                 | ___ \     
+  | |_ __ _   _ ___ ___ | |_/ /   _ 
+  | | '__| | | / __/ __||  __/ | | |
+  | | |  | |_| \__ \__ \| |  | |_| |
+  \_/_|   \__,_|___/___/\_|   \__, |
+                               __/ |
+                              |___/ 
+
+TrussPy - Truss Solver for Python
+          Version {__version__}
+
+Dutzler Andreas, Graz University of Technology, 2023
         """
             )
+        if self.logfile:
+            print("```")
 
         if log > 1:
             print("")
@@ -171,14 +139,11 @@ class Model:
         self.Boundaries = BoundaryHandler()
         self.ExtForces = ExternalForceHandler()
         self.Settings = SettingsHandler()
-        # self.Results = ResultHandler()
-        # self.Analysis = Analysis()
 
         self.Settings.log = log
 
         if log > 1:
             print("    - finished.\n")
-        # if log > 1: print('-'*88+'\n')
 
         if file is not None:
             if log > 1:
@@ -230,10 +195,9 @@ class Model:
 
             if log > 1:
                 print("    - Import finished.\n")
-            # if log > 1: print('-'*88)
 
     def build(self):
-        """build Model (r,U,K,...) with Model data and dimensions."""
+        "Build Model (r,U,K,...) with Model data and dimensions."
 
         self.Results = ResultHandler()
         self.Analysis = Analysis()
@@ -262,8 +226,7 @@ class Model:
         if 2 in self.Elements.mat_type:
             self.Settings.nstatev = 2
 
-        # node properties
-        # n----pro-------
+        # (n)ode (pro)perties
         #
         #      active = free  = 1
         #    inactive = fixed = 0
@@ -408,10 +371,6 @@ class Model:
         self.Analysis.Vred = np.append(self.Analysis.Ured, 0)
         self.Analysis.lpf = 0
 
-        # init LPF
-        # self.Settings.lpf = self.Settings.dlpf
-        # self.Analysis.lpf = self.Settings.dlpf
-
         for step in range(self.Settings.nsteps):
 
             # maximum number of increment and maximum value per step
@@ -435,9 +394,6 @@ class Model:
 
                 print(r"$$\text{Value}_i = \left|\frac{D_x}{D_{x,max}}\right|_i$$")
 
-            # get reduced external force vector
-            # f0red = self.ExtForces.forces[:,3*(step):3*(step+1)].flatten()[self.Analysis.DOF1]
-            # self.Analysis.f0red = f0red.reshape(len(f0red),1)
             self.Analysis.ExtForces = copy.deepcopy(self.ExtForces)
 
             f0_const = np.zeros_like(
@@ -554,17 +510,17 @@ class Model:
 
         if self.logfile:
             sys.stdout = self.stdout
-            sp_run(
-                [
-                    "pandoc",
-                    self.logfile_name + ".md",
-                    "-t",
-                    "latex",
-                    "-o",
-                    self.logfile_name + ".pdf",
-                ]
-            )
             if self.Settings.logpdf:
+                sp_run(
+                    [
+                        "pandoc",
+                        self.logfile_name + ".md",
+                        "-t",
+                        "latex",
+                        "-o",
+                        self.logfile_name + ".pdf",
+                    ]
+                )
                 sp_run(
                     [
                         "pandoc",
@@ -578,15 +534,11 @@ class Model:
                 )
 
     def stiffness(self, Ured, analysis=None):
-        "Method for Stiffness Matrix."
-
-        # In a future version this function should be implemented in Stiffness class part of the Model or Results
-        # self.Stiffness(reduced=True)
-
-        # it re-shapes stiffness matrix to
-        # K(nnodes,nnodes,ndim,ndim) --> K(nnodes*ndim,nnodes*nim)
-        # and returns a view on the reduced (active part of the) matrix
-        # K(nnodes*ndim,nnodes*nim)[active DOF rows][:,active DOF columns]
+        """Method for evaluating the stiffness matrix. It re-shapes the stiffness matrix
+        to ``K(nnodes,nnodes,ndim,ndim) --> K(nnodes*ndim,nnodes*nim)`` and returns a
+        view on the reduced (active part of the) matrix
+        ``K(nnodes*ndim,nnodes*nim)[active DOF rows][:,active DOF columns]``.
+        """
 
         if analysis is not None:
             self.Analysis = analysis
@@ -611,7 +563,7 @@ class Model:
         return self.Analysis.Kred
 
     def equilibrium(self, Ured, U0red, stage="G", analysis=None, statev_write=False):
-        """Method to generate equilibrium for given displacements and external forces."""
+        "Method to generate equilibrium for given displacements and external forces."
 
         if analysis is not None:
             self.Analysis = analysis
@@ -619,7 +571,6 @@ class Model:
         # remove last entry in Vred to get only displacement DOFs
         if len(Ured) > self.ndof1:
             lpf = Ured[-1]
-            lpf0 = U0red[-1]
             Ured = Ured[: self.ndof1]
             U0red = U0red[: self.ndof1]
         else:
@@ -676,14 +627,11 @@ class Model:
                 rnodes[n] = self.Analysis.r[np.where(self.Nodes.labels == node)][0]
 
             mat_type = self.Elements.get_material_type(e)
-            # elem_type = self.Elements.get_element_type(e)
 
             if mat_type == 1:
                 umat = umat_el
             elif mat_type == 2:
                 umat = umat_elplast_iso
-            elif mat_type == 3:
-                umat = umat_elplast_kiniso
 
             self.Analysis, state_v = truss(
                 e,
@@ -702,7 +650,6 @@ class Model:
                 self.Analysis,
             )
             if statev_write and self.Settings.nstatev > 0:
-                # print('write state-variable for element', int(e), state_v[0])
                 self.Analysis.state_v = state_v
                 self.Analysis.lpf = lpf
                 self.Analysis.Vred = np.append(Ured, lpf)
